@@ -9,7 +9,7 @@ from typing_extensions import Literal, NotRequired, TypeAlias, TypedDict
 import unipressed.base
 
 
-class LocationsQuery(TypedDict):
+class LocationsQueryDict(TypedDict):
     and_: NotRequired[Iterable["LocationsQuery"]]
     "Two or more filters that must both be satisfied"
     or_: NotRequired[Iterable["LocationsQuery"]]
@@ -17,11 +17,12 @@ class LocationsQuery(TypedDict):
     not_: NotRequired[Iterable["LocationsQuery"]]
     "Negate a filter"
     name: NotRequired[str]
-    "Name"
+    "Name\ne.g. A band"
     id: NotRequired[str]
-    "Location [AC]"
+    "Location [AC]\ne.g. SL-0476"
 
 
+LocationsQuery: TypeAlias = Union[LocationsQueryDict, str]
 LocationsSubcellularLocation: TypeAlias = Literal[
     "id",
     "name",
